summaryrefslogtreecommitdiff
path: root/drivers/media/common/siano/smsdvb.h
diff options
context:
space:
mode:
authorMauro Carvalho Chehab <mchehab@redhat.com>2013-03-21 16:06:03 +0400
committerMauro Carvalho Chehab <mchehab@redhat.com>2013-03-21 17:03:27 +0400
commitcf0e9cfcc70d8aaeabf19356f42041f8a5495301 (patch)
tree52e12c6e0d1027a0c280ed78f67a31166a64796e /drivers/media/common/siano/smsdvb.h
parentdfef84fc135832ad5c270758b6834fcb4bf448fc (diff)
downloadlinux-cf0e9cfcc70d8aaeabf19356f42041f8a5495301.tar.xz
[media] siano: convert structure names to lowercase
There are several structures defined in uppercase. Convert them to lowercase, and simplify their names, when possible. Signed-off-by: Mauro Carvalho Chehab <mchehab@redhat.com>
Diffstat (limited to 'drivers/media/common/siano/smsdvb.h')
-rw-r--r--drivers/media/common/siano/smsdvb.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/drivers/media/common/siano/smsdvb.h b/drivers/media/common/siano/smsdvb.h
index e1ff07c2e6c8..513f85366209 100644
--- a/drivers/media/common/siano/smsdvb.h
+++ b/drivers/media/common/siano/smsdvb.h
@@ -19,14 +19,14 @@ struct smsdvb_debugfs;
struct smsdvb_client_t;
typedef void (*sms_prt_dvb_stats_t)(struct smsdvb_debugfs *debug_data,
- struct SMSHOSTLIB_STATISTICS_ST *p);
+ struct sms_stats *p);
typedef void (*sms_prt_isdb_stats_t)(struct smsdvb_debugfs *debug_data,
- struct SMSHOSTLIB_STATISTICS_ISDBT_ST *p);
+ struct sms_isdbt_stats *p);
typedef void (*sms_prt_isdb_stats_ex_t)
(struct smsdvb_debugfs *debug_data,
- struct SMSHOSTLIB_STATISTICS_ISDBT_EX_ST *p);
+ struct sms_isdbt_stats_ex *p);
struct smsdvb_client_t {
@@ -68,7 +68,8 @@ struct smsdvb_client_t {
};
/*
* This struct is a mix of RECEPTION_STATISTICS_EX_S and SRVM_SIGNAL_STATUS_S.
* It was obtained by comparing the way it was filled by the original code
*/
struct RECEPTION_STATISTICS_PER_SLICES_S {
@@ -68,7 +68,8 @@ struct smsdvb_client_t {
};
/*
- * This struct is a mix of RECEPTION_STATISTICS_EX_S and SRVM_SIGNAL_STATUS_S.
+ * This struct is a mix of struct sms_rx_stats_ex and
+ * struct sms_srvm_signal_status.
* It was obtained by comparing the way it was filled by the original code
*/